@@ -298,7 +298,7 @@ func TestFindFirstHitSimple(t *testing.T) {
 
 	pager.searchPattern = toPattern("AB")
 
-	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, nil, false)
 	assert.Assert(t, hit.internalDontTouch.lineNumber.IsZero())
 	assert.Equal(t, hit.internalDontTouch.deltaScreenLines, 0)
 }
@@ -312,7 +312,7 @@ func TestFindFirstHitAnsi(t *testing.T) {
 
 	pager.searchPattern = toPattern("AB")
 
-	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, nil, false)
 	assert.Assert(t, hit.internalDontTouch.lineNumber.IsZero())
 	assert.Equal(t, hit.internalDontTouch.deltaScreenLines, 0)
 }
@@ -326,7 +326,7 @@ func TestFindFirstHitNoMatch(t *testing.T) {
 
 	pager.searchPattern = toPattern("this pattern should not be found")
 
-	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, nil, false)
 	assert.Assert(t, hit == nil)
 }
 
@@ -340,7 +340,7 @@ func TestFindFirstHitNoMatchBackwards(t *testing.T) {
 	pager.searchPattern = toPattern("this pattern should not be found")
 	theEnd := *linenumbers.LineNumberFromLength(reader.GetLineCount())
 
-	hit := pager.findFirstHit(theEnd, true)
+	hit := pager.findFirstHit(theEnd, nil, true)
 	assert.Assert(t, hit == nil)
 }
 
@@ -682,7 +682,7 @@ func benchmarkSearch(b *testing.B, highlighted bool) {
 	b.ResetTimer()
 
 	// This test will search through all the N copies we made of our file
-	hit := pager.findFirstHit(linenumbers.LineNumber{}, false)
+	hit := pager.findFirstHit(linenumbers.LineNumber{}, nil, false)
 
 	if hit != nil {
 		panic(fmt.Errorf("This test is meant to scan the whole file without finding anything"))
